Class: Aws::SageMakerFeatureStoreRuntime::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb,
sig/client.rbs

Overview

An API client for SageMakerFeatureStoreRuntime. To construct a client, you need to configure a :region and :credentials.

client = Aws::SageMakerFeatureStoreRuntime::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the developer guide.

See #initialize for a full list of supported configuration options.

Defined Under Namespace

Modules: _BatchGetRecordResponseSuccess, _BatchWriteRecordResponseSuccess, _GetRecordResponseSuccess, _ListRecordsResponseSuccess

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements Aws::CredentialProvider, or instance of any one of the following classes:

    • Aws::Credentials - Used for configuring static, non-refreshing credentials.

    • Aws::SharedCredentials - Used for loading static credentials from a shared file, such as ~/.aws/config.

    • Aws::AssumeRoleCredentials - Used when you need to assume a role.

    • Aws::AssumeRoleWebIdentityCredentials - Used when you need to assume a role after providing credentials via the web.

    • Aws::SSOCredentials - Used for loading credentials from AWS SSO using an access token generated from aws login.

    • Aws::ProcessCredentials - Used for loading credentials from a process that outputs to stdout.

    • Aws::InstanceProfileCredentials - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • Aws::ECSCredentials - Used for loading credentials from instances running in ECS.

    • Aws::CognitoIdentityCredentials - Used for loading credentials from the Cognito Identity service.

    When :credentials are not configured directly, the following locations will be searched for credentials:

    • Aws.config[:credentials]

    • The :access_key_id, :secret_access_key, :session_token, and :account_id options.

    • ENV['AWS_ACCESS_KEY_ID'], ENV['AWS_SECRET_ACCESS_KEY'], ENV['AWS_SESSION_TOKEN'], and ENV['AWS_ACCOUNT_ID'].

    • ~/.aws/credentials

    • ~/.aws/config

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of Aws::InstanceProfileCredentials or Aws::ECSCredentials to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting ENV['AWS_EC2_METADATA_DISABLED'] to true.

  • :region (required, String)

    The AWS region to connect to. The configured :region is used to determine the service :endpoint. When not passed, a default :region is searched for in the following locations:

    • Aws.config[:region]
    • ENV['AWS_REGION']
    • ENV['AMAZON_REGION']
    • ENV['AWS_DEFAULT_REGION']
    • ~/.aws/credentials
    • ~/.aws/config
  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to true, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to false.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in adaptive retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a RetryCapacityNotAvailableError and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: sigv4, sigv4a, httpBearerAuth, and noAuth. When set using ENV['AWS_AUTH_SCHEME_PREFERENCE'] or in shared config as auth_scheme_preference, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When true, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When true, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in standard and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When true, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to 'true' the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the :endpoint option directly. This is normally constructed from the :region option. Configuring :endpoint is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to true, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the :logger at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in standard and adaptive retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at HOME/.aws/credentials. When not specified, 'default' is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • when_supported - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the httpChecksum trait where requestChecksumRequired is true and/or a requestAlgorithmMember is modeled.
    • when_required - When set, a checksum will only be calculated for request payloads of operations modeled with the httpChecksum trait where requestChecksumRequired is true or where a requestAlgorithmMember is modeled and supplied.
  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • when_supported - (default) When set, checksum validation is performed on all response payloads of operations modeled with the httpChecksum trait where responseAlgorithms is modeled, except when no modeled checksum algorithms are supported.
    • when_required - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the requestValidationModeMember member is set to ENABLED.
  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the legacy retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the legacy retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the legacy retry mode.

    @see https://www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the legacy retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the legacy retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • legacy - The pre-existing retry behavior. This is the default value if no retry mode is provided.

    • standard - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • adaptive - A retry mode that includes all the functionality of standard mode along with automatic client side throttling.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default :sigv4a_signing_region_set is searched for in the following locations:

    • Aws.config[:sigv4a_signing_region_set]
    • ENV['AWS_SIGV4A_SIGNING_REGION_SET']
    • ~/.aws/config
  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses NoOpTelemetryProvider which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the opentelemetry-sdk gem and then, pass in an instance of a Aws::Telemetry::OTelProvider for telemetry provider.
  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements Aws::TokenProvider, or instance of any one of the following classes:

    • Aws::StaticTokenProvider - Used for configuring static, non-refreshing tokens.

    • Aws::SSOTokenProvider - Used for loading tokens from AWS SSO using an access token generated from aws login.

    When :token_provider is not configured directly, the Aws::TokenProviderChain will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to true, dualstack enabled endpoints (with .aws TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to true, fips compatible endpoints will be used if available. When a fips region is used, the region is normalized and this config is set to true.

  • :validate_params (Boolean) — default: true

    When true, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::SageMakerFeatureStoreRuntime::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to #resolve_endpoint(parameters) where parameters is a Struct similar to Aws::SageMakerFeatureStoreRuntime::EndpointParameters.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has "Expect" header set to "100-continue". Defaults to nil which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like 'http://proxy.com:123'.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When true, HTTP debug output will be sent to the :logger.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a content-length).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When true, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass :ssl_ca_bundle or :ssl_ca_directory the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass :ssl_ca_bundle or :ssl_ca_directory the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When true, SSL peer certificates are verified when establishing a connection.



471
472
473
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 471

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



968
969
970
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 968

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



971
972
973
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 971

def errors_module
  Errors
end

Instance Method Details

#batch_get_record(params = {}) ⇒ Types::BatchGetRecordResponse

Retrieves a batch of Records from a FeatureGroup.

Examples:

Request syntax with placeholder values


resp = client.batch_get_record({
  identifiers: [ # required
    {
      feature_group_name: "FeatureGroupNameOrArn", # required
      record_identifiers_value_as_string: ["ValueAsString"], # required
      feature_names: ["FeatureName"],
    },
  ],
  expiration_time_response: "Enabled", # accepts Enabled, Disabled
})

Response structure


resp.records #=> Array
resp.records[0].feature_group_name #=> String
resp.records[0].record_identifier_value_as_string #=> String
resp.records[0].record #=> Array
resp.records[0].record[0].feature_name #=> String
resp.records[0].record[0].value_as_string #=> String
resp.records[0].record[0].value_as_string_list #=> Array
resp.records[0].record[0].value_as_string_list[0] #=> String
resp.records[0].expires_at #=> String
resp.errors #=> Array
resp.errors[0].feature_group_name #=> String
resp.errors[0].record_identifier_value_as_string #=> String
resp.errors[0].error_code #=> String
resp.errors[0].error_message #=> String
resp.unprocessed_identifiers #=> Array
resp.unprocessed_identifiers[0].feature_group_name #=> String
resp.unprocessed_identifiers[0].record_identifiers_value_as_string #=> Array
resp.unprocessed_identifiers[0].record_identifiers_value_as_string[0] #=> String
resp.unprocessed_identifiers[0].feature_names #=> Array
resp.unprocessed_identifiers[0].feature_names[0] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :identifiers (required, Array<Types::BatchGetRecordIdentifier>)

    A list containing the name or Amazon Resource Name (ARN) of the FeatureGroup, the list of names of Features to be retrieved, and the corresponding RecordIdentifier values as strings.

  • :expiration_time_response (String)

    Parameter to request ExpiresAt in response. If Enabled, BatchGetRecord will return the value of ExpiresAt, if it is not null. If Disabled and null, BatchGetRecord will return null.

Returns:

See Also:



88
# File 'sig/client.rbs', line 88

def batch_get_record: (

#batch_write_record(params = {}) ⇒ Types::BatchWriteRecordResponse

Writes a batch of Records to one or more FeatureGroups. Use this API for bulk ingestion of records into the OnlineStore and OfflineStore.

You can set the ingested records to expire at a given time to live (TTL) duration after the record's event time by specifying the TtlDuration parameter. A request level TtlDuration applies to all entries that do not specify their own TtlDuration.

Examples:

Example: Write records to multiple feature groups


resp = client.batch_write_record({
  entries: [
    {
      feature_group_name: "my-feature-group", 
      record: [
        {
          feature_name: "customer_id", 
          value_as_string: "cust-001", 
        }, 
        {
          feature_name: "age", 
          value_as_string: "25", 
        }, 
      ], 
    }, 
  ], 
})

resp.to_h outputs the following:
{
  errors: [
  ], 
  unprocessed_entries: [
  ], 
}

Request syntax with placeholder values


resp = client.batch_write_record({
  entries: [ # required
    {
      feature_group_name: "FeatureGroupNameOrArn", # required
      record: [ # required
        {
          feature_name: "FeatureName", # required
          value_as_string: "ValueAsString",
          value_as_string_list: ["ValueAsString"],
        },
      ],
      target_stores: ["OnlineStore"], # accepts OnlineStore, OfflineStore
      ttl_duration: {
        unit: "Seconds", # required, accepts Seconds, Minutes, Hours, Days, Weeks
        value: 1, # required
      },
    },
  ],
  ttl_duration: {
    unit: "Seconds", # required, accepts Seconds, Minutes, Hours, Days, Weeks
    value: 1, # required
  },
})

Response structure


resp.errors #=> Array
resp.errors[0].entry.feature_group_name #=> String
resp.errors[0].entry.record #=> Array
resp.errors[0].entry.record[0].feature_name #=> String
resp.errors[0].entry.record[0].value_as_string #=> String
resp.errors[0].entry.record[0].value_as_string_list #=> Array
resp.errors[0].entry.record[0].value_as_string_list[0] #=> String
resp.errors[0].entry.target_stores #=> Array
resp.errors[0].entry.target_stores[0] #=> String, one of "OnlineStore", "OfflineStore"
resp.errors[0].entry.ttl_duration.unit #=> String, one of "Seconds", "Minutes", "Hours", "Days", "Weeks"
resp.errors[0].entry.ttl_duration.value #=> Integer
resp.errors[0].error_code #=> String
resp.errors[0].error_message #=> String
resp.unprocessed_entries #=> Array
resp.unprocessed_entries[0].feature_group_name #=> String
resp.unprocessed_entries[0].record #=> Array
resp.unprocessed_entries[0].record[0].feature_name #=> String
resp.unprocessed_entries[0].record[0].value_as_string #=> String
resp.unprocessed_entries[0].record[0].value_as_string_list #=> Array
resp.unprocessed_entries[0].record[0].value_as_string_list[0] #=> String
resp.unprocessed_entries[0].target_stores #=> Array
resp.unprocessed_entries[0].target_stores[0] #=> String, one of "OnlineStore", "OfflineStore"
resp.unprocessed_entries[0].ttl_duration.unit #=> String, one of "Seconds", "Minutes", "Hours", "Days", "Weeks"
resp.unprocessed_entries[0].ttl_duration.value #=> Integer

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :entries (required, Array<Types::BatchWriteRecordEntry>)

    A list of records to write. Each entry specifies the FeatureGroup, the record data, and optionally target stores and a TTL duration.

  • :ttl_duration (Types::TtlDuration)

    Time to live duration applied to all entries in the batch that do not specify their own TtlDuration; ExpiresAt = EventTime + TtlDuration. For information on HardDelete, see the DeleteRecord API in the Amazon SageMaker API Reference guide.

Returns:

See Also:



106
# File 'sig/client.rbs', line 106

def batch_write_record: (

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 941

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::SageMakerFeatureStoreRuntime')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-sagemakerfeaturestoreruntime'
  context[:gem_version] = '1.66.0'
  Seahorse::Client::Request.new(handlers, context)
end

#delete_record(params = {}) ⇒ Struct

Deletes a Record from a FeatureGroup in the OnlineStore. Feature Store supports both SoftDelete and HardDelete. For SoftDelete (default), feature columns are set to null and the record is no longer retrievable by GetRecord or BatchGetRecord. For HardDelete, the complete Record is removed from the OnlineStore. In both cases, Feature Store appends the deleted record marker to the OfflineStore. The deleted record marker is a record with the same RecordIdentifer as the original, but with is_deleted value set to True, EventTime set to the delete input EventTime, and other feature values set to null.

Note that the EventTime specified in DeleteRecord should be set later than the EventTime of the existing record in the OnlineStore for that RecordIdentifer. If it is not, the deletion does not occur:

  • For SoftDelete, the existing (not deleted) record remains in the OnlineStore, though the delete record marker is still written to the OfflineStore.

  • HardDelete returns EventTime: 400 ValidationException to indicate that the delete operation failed. No delete record marker is written to the OfflineStore.

When a record is deleted from the OnlineStore, the deleted record marker is appended to the OfflineStore. If you have the Iceberg table format enabled for your OfflineStore, you can remove all history of a record from the OfflineStore using Amazon Athena or Apache Spark. For information on how to hard delete a record from the OfflineStore with the Iceberg table format enabled, see Delete records from the offline store.

Examples:

Request syntax with placeholder values


resp = client.delete_record({
  feature_group_name: "FeatureGroupNameOrArn", # required
  record_identifier_value_as_string: "ValueAsString", # required
  event_time: "ValueAsString", # required
  target_stores: ["OnlineStore"], # accepts OnlineStore, OfflineStore
  deletion_mode: "SoftDelete", # accepts SoftDelete, HardDelete
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :feature_group_name (required, String)

    The name or Amazon Resource Name (ARN) of the feature group to delete the record from.

  • :record_identifier_value_as_string (required, String)

    The value for the RecordIdentifier that uniquely identifies the record, in string format.

  • :event_time (required, String)

    Timestamp indicating when the deletion event occurred. EventTime can be used to query data at a certain point in time.

  • :target_stores (Array<String>)

    A list of stores from which you're deleting the record. By default, Feature Store deletes the record from all of the stores that you're using for the FeatureGroup.

  • :deletion_mode (String)

    The name of the deletion mode for deleting the record. By default, the deletion mode is set to SoftDelete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



132
# File 'sig/client.rbs', line 132

def delete_record: (

#get_record(params = {}) ⇒ Types::GetRecordResponse

Use for OnlineStore serving from a FeatureStore. Only the latest records stored in the OnlineStore can be retrieved. If no Record with RecordIdentifierValue is found, then an empty result is returned.

Examples:

Request syntax with placeholder values


resp = client.get_record({
  feature_group_name: "FeatureGroupNameOrArn", # required
  record_identifier_value_as_string: "ValueAsString", # required
  feature_names: ["FeatureName"],
  expiration_time_response: "Enabled", # accepts Enabled, Disabled
})

Response structure


resp.record #=> Array
resp.record[0].feature_name #=> String
resp.record[0].value_as_string #=> String
resp.record[0].value_as_string_list #=> Array
resp.record[0].value_as_string_list[0] #=> String
resp.expires_at #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :feature_group_name (required, String)

    The name or Amazon Resource Name (ARN) of the feature group from which you want to retrieve a record.

  • :record_identifier_value_as_string (required, String)

    The value that corresponds to RecordIdentifier type and uniquely identifies the record in the FeatureGroup.

  • :feature_names (Array<String>)

    List of names of Features to be retrieved. If not specified, the latest value for all the Features are returned.

  • :expiration_time_response (String)

    Parameter to request ExpiresAt in response. If Enabled, GetRecord will return the value of ExpiresAt, if it is not null. If Disabled and null, GetRecord will return null.

Returns:

See Also:



147
# File 'sig/client.rbs', line 147

def get_record: (

#list_records(params = {}) ⇒ Types::ListRecordsResponse

Lists the RecordIdentifier values of all records stored in a FeatureGroup's OnlineStore. This enables you to discover which records exist without retrieving the full record data.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Example: List record identifiers from a feature group


resp = client.list_records({
  feature_group_name: "my-feature-group", 
  max_results: 10, 
})

resp.to_h outputs the following:
{
  next_token: "eyJsYXN0RXZhbHVhdGVkS2V5IjoiYWJjMTIzIn0=", 
  record_identifiers: [
    "record-id-1", 
    "record-id-2", 
  ], 
}

Request syntax with placeholder values


resp = client.list_records({
  feature_group_name: "FeatureGroupNameOrArn", # required
  max_results: 1,
  next_token: "ListRecordsNextToken",
  include_soft_deleted_records: false,
})

Response structure


resp.record_identifiers #=> Array
resp.record_identifiers[0] #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :feature_group_name (required, String)

    The name or Amazon Resource Name (ARN) of the feature group to list records from.

  • :max_results (Integer)

    The maximum number of record identifiers to return in a single page of results. For the InMemory tier, this value is a hint and not a strict requirement. The response may contain more or fewer results than the specified MaxResults.

  • :next_token (String)

    A token to resume pagination of ListRecords results.

  • :include_soft_deleted_records (Boolean)

    If set to true, the result includes records that have been soft deleted.

Returns:

See Also:



161
# File 'sig/client.rbs', line 161

def list_records: (

#put_record(params = {}) ⇒ Struct

The PutRecord API is used to ingest a list of Records into your feature group.

If a new record’s EventTime is greater, the new record is written to both the OnlineStore and OfflineStore. Otherwise, the record is a historic record and it is written only to the OfflineStore.

You can specify the ingestion to be applied to the OnlineStore, OfflineStore, or both by using the TargetStores request parameter.

You can set the ingested record to expire at a given time to live (TTL) duration after the record’s event time, ExpiresAt = EventTime + TtlDuration, by specifying the TtlDuration parameter. A record level TtlDuration is set when specifying the TtlDuration parameter using the PutRecord API call. If the input TtlDuration is null or unspecified, TtlDuration is set to the default feature group level TtlDuration. A record level TtlDuration supersedes the group level TtlDuration.

Examples:

Request syntax with placeholder values


resp = client.put_record({
  feature_group_name: "FeatureGroupNameOrArn", # required
  record: [ # required
    {
      feature_name: "FeatureName", # required
      value_as_string: "ValueAsString",
      value_as_string_list: ["ValueAsString"],
    },
  ],
  target_stores: ["OnlineStore"], # accepts OnlineStore, OfflineStore
  ttl_duration: {
    unit: "Seconds", # required, accepts Seconds, Minutes, Hours, Days, Weeks
    value: 1, # required
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :feature_group_name (required, String)

    The name or Amazon Resource Name (ARN) of the feature group that you want to insert the record into.

  • :record (required, Array<Types::FeatureValue>)

    List of FeatureValues to be inserted. This will be a full over-write. If you only want to update few of the feature values, do the following:

    • Use GetRecord to retrieve the latest record.

    • Update the record returned from GetRecord.

    • Use PutRecord to update feature values.

  • :target_stores (Array<String>)

    A list of stores to which you're adding the record. By default, Feature Store adds the record to all of the stores that you're using for the FeatureGroup.

  • :ttl_duration (Types::TtlDuration)

    Time to live duration, where the record is hard deleted after the expiration time is reached; ExpiresAt = EventTime + TtlDuration. For information on HardDelete, see the DeleteRecord API in the Amazon SageMaker API Reference guide.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



170
# File 'sig/client.rbs', line 170

def put_record: (

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


961
962
963
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 961

def waiter_names
  []
end