Class: Aws::SageMakerFeatureStoreRuntime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SageMakerFeatureStoreRuntime::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb,
sig/client.rbs
Overview
An API client for SageMakerFeatureStoreRuntime. To construct a client, you need to configure a :region and :credentials.
client = Aws::SageMakerFeatureStoreRuntime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetRecordResponseSuccess, _BatchWriteRecordResponseSuccess, _GetRecordResponseSuccess, _ListRecordsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_record(params = {}) ⇒ Types::BatchGetRecordResponse
Retrieves a batch of
Recordsfrom aFeatureGroup. -
#batch_write_record(params = {}) ⇒ Types::BatchWriteRecordResponse
Writes a batch of
Recordsto one or moreFeatureGroups. -
#delete_record(params = {}) ⇒ Struct
Deletes a
Recordfrom aFeatureGroupin theOnlineStore. -
#get_record(params = {}) ⇒ Types::GetRecordResponse
Use for
OnlineStoreserving from aFeatureStore. -
#list_records(params = {}) ⇒ Types::ListRecordsResponse
Lists the
RecordIdentifiervalues of all records stored in aFeatureGroup'sOnlineStore. -
#put_record(params = {}) ⇒ Struct
The
PutRecordAPI is used to ingest a list ofRecordsinto your feature group.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
968 969 970 |
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 968 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
971 972 973 |
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 971 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_record(params = {}) ⇒ Types::BatchGetRecordResponse
Retrieves a batch of Records from a FeatureGroup.
88 |
# File 'sig/client.rbs', line 88
def batch_get_record: (
|
#batch_write_record(params = {}) ⇒ Types::BatchWriteRecordResponse
Writes a batch of Records to one or more FeatureGroups. Use this
API for bulk ingestion of records into the OnlineStore and
OfflineStore.
You can set the ingested records to expire at a given time to live
(TTL) duration after the record's event time by specifying the
TtlDuration parameter. A request level TtlDuration applies to all
entries that do not specify their own TtlDuration.
106 |
# File 'sig/client.rbs', line 106
def batch_write_record: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 |
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 941 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SageMakerFeatureStoreRuntime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sagemakerfeaturestoreruntime' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_record(params = {}) ⇒ Struct
Deletes a Record from a FeatureGroup in the OnlineStore. Feature
Store supports both SoftDelete and HardDelete. For SoftDelete
(default), feature columns are set to null and the record is no
longer retrievable by GetRecord or BatchGetRecord. For
HardDelete, the complete Record is removed from the OnlineStore.
In both cases, Feature Store appends the deleted record marker to the
OfflineStore. The deleted record marker is a record with the same
RecordIdentifer as the original, but with is_deleted value set to
True, EventTime set to the delete input EventTime, and other
feature values set to null.
Note that the EventTime specified in DeleteRecord should be set
later than the EventTime of the existing record in the OnlineStore
for that RecordIdentifer. If it is not, the deletion does not occur:
-
For
SoftDelete, the existing (not deleted) record remains in theOnlineStore, though the delete record marker is still written to theOfflineStore. -
HardDeletereturnsEventTime:400 ValidationExceptionto indicate that the delete operation failed. No delete record marker is written to theOfflineStore.
When a record is deleted from the OnlineStore, the deleted record
marker is appended to the OfflineStore. If you have the Iceberg
table format enabled for your OfflineStore, you can remove all
history of a record from the OfflineStore using Amazon Athena or
Apache Spark. For information on how to hard delete a record from the
OfflineStore with the Iceberg table format enabled, see Delete
records from the offline store.
132 |
# File 'sig/client.rbs', line 132
def delete_record: (
|
#get_record(params = {}) ⇒ Types::GetRecordResponse
Use for OnlineStore serving from a FeatureStore. Only the latest
records stored in the OnlineStore can be retrieved. If no Record
with RecordIdentifierValue is found, then an empty result is
returned.
147 |
# File 'sig/client.rbs', line 147
def get_record: (
|
#list_records(params = {}) ⇒ Types::ListRecordsResponse
Lists the RecordIdentifier values of all records stored in a
FeatureGroup's OnlineStore. This enables you to discover which
records exist without retrieving the full record data.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
161 |
# File 'sig/client.rbs', line 161
def list_records: (
|
#put_record(params = {}) ⇒ Struct
The PutRecord API is used to ingest a list of Records into your
feature group.
If a new record’s EventTime is greater, the new record is written to
both the OnlineStore and OfflineStore. Otherwise, the record is a
historic record and it is written only to the OfflineStore.
You can specify the ingestion to be applied to the OnlineStore,
OfflineStore, or both by using the TargetStores request parameter.
You can set the ingested record to expire at a given time to live
(TTL) duration after the record’s event time, ExpiresAt =
EventTime + TtlDuration, by specifying the TtlDuration
parameter. A record level TtlDuration is set when specifying the
TtlDuration parameter using the PutRecord API call. If the input
TtlDuration is null or unspecified, TtlDuration is set to the
default feature group level TtlDuration. A record level
TtlDuration supersedes the group level TtlDuration.
170 |
# File 'sig/client.rbs', line 170
def put_record: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
961 962 963 |
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/client.rb', line 961 def waiter_names [] end |