Class: Aws::SageMakerFeatureStoreRuntime::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMakerFeatureStoreRuntime::Types::ConflictException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerfeaturestoreruntime/types.rb
Overview
The service rejected the update because the provided EventTime is
older than the record's current EventTime. To persist the update,
retrieve the record's latest EventTime and resubmit the request
with an EventTime that is equal to or newer than the current value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
280 281 282 283 284 |
# File 'lib/aws-sdk-sagemakerfeaturestoreruntime/types.rb', line 280 class ConflictException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |